diff --git a/gradle.properties b/gradle.properties
index a71729e1..0d30378d 100644
--- a/gradle.properties
+++ b/gradle.properties
@@ -27,6 +27,7 @@ zookeeperVersion=3.4.6
hbaseVersion=1.2.4
hcatalogVersion=1.2.1
kryoVersion=2.22
+calciteVersion=1.2.0-incubating
guavaVersion=14.0.1
accumuloVersion=1.6.2
diff --git a/ivy.xml b/ivy.xml
index 18448602..670cb32d 100644
--- a/ivy.xml
+++ b/ivy.xml
@@ -210,8 +210,9 @@ under the License.
-
+
+
diff --git a/ivy/libraries.properties b/ivy/libraries.properties
index 2f1ec9e5..8f3dab2b 100644
--- a/ivy/libraries.properties
+++ b/ivy/libraries.properties
@@ -59,6 +59,7 @@ hadoop.version=2.8.0
hbase.version=1.2.4
hcatalog.version=1.2.1
kryo.version=2.22
+calcite.version=1.2.0-incubating
jackson-databind.version=2.9.5
parquet.version=1.6.0
diff --git a/build.gradle b/build.gradle
index 9a2b55cf..fc7fc0c4 100644
--- a/build.gradle
+++ b/build.gradle
@@ -111,8 +111,9 @@ dependencies {
exclude group: 'org.apache.hive', module: 'hive-exec'
}
common group: 'org.apache.hive', name: 'hive-exec', version: hcatalogVersion, classifier: 'core'
// Kryo is a dependency of hive-exec:core
common group: 'com.esotericsoftware.kryo', name: 'kryo', version: kryoVersion
+ common group: 'org.apache.calcite', name: 'calcite-core', version: calciteVersion
common (group: 'org.apache.hive', name: 'hive-jdbc', version: hcatalogVersion) {
exclude group: 'org.apache.avro', module: 'avro'
}
@@ -111,8 +111,9 @@ dependencies {
}
common group: 'org.apache.hive', name: 'hive-exec', version: hcatalogVersion, classifier: 'core'
- // Kryo is a dependency of hive-exec:core
+ // Kryo and calcite are dependencies of hive-exec:core
common group: 'com.esotericsoftware.kryo', name: 'kryo', version: kryoVersion